@@ -1,3 +1,5 @@
+use crate::ThreadName;
+
 ///Raw thread id type, which is dummy on this platform
 pub type RawId = u8;
 
@@ -15,9 +17,8 @@ pub fn raw_thread_eq(left: RawId, right: RawId) -> bool {
     left == right
 }
 
-#[cfg(feature = "thread-name")]
 #[inline(always)]
 ///Returns empty thread name as this target has no concept of threads.
-pub fn get_current_thread_name() -> str_buf::StrBuf::<16> {
-    str_buf::StrBuf::new()
+pub fn get_current_thread_name() -> ThreadName {
+    ThreadName::new()
 }
