@@ -1,4 +1,4 @@
-use os_id::ThreadId;
+use os_id::{ThreadName, ThreadId};
 
 #[test]
 fn should_use_current_thread() {
@@ -16,7 +16,6 @@ fn should_use_current_thread() {
     assert_ne!(thread1.as_raw(), another_thread.as_raw());
 }
 
-#[cfg(feature = "thread-name")]
 #[test]
 fn should_get_current_thread_name() {
     std::thread::Builder::new().name("test".to_owned()).spawn(|| {
@@ -26,4 +25,18 @@ fn should_get_current_thread_name() {
 
     let name = os_id::thread::get_current_thread_name();
     assert_ne!(name, "test");
+    assert_ne!(name.as_str(), Ok("test"));
+}
+
+#[test]
+fn verify_thread_name_struct() {
+    const DATA: &str = "1234567891234567";
+
+    for idx in 0..DATA.len() {
+        let mut buf = [0u8; 16];
+        buf[..idx].copy_from_slice(&DATA.as_bytes()[..idx]);
+        let name = ThreadName::name(buf);
+        assert_eq!(name, &DATA.as_bytes()[..idx]);
+        assert_eq!(name.as_str(), Ok(&DATA[..idx]));
+    }
 }
